# Build the dataFileFormats list
from typing import Dict, List, Set

from .abstractdatafileformat import AbstractDataFileFormat
from .jsondatafile import JsonDataFile
from .yamldatafile import YamlDataFile

"""
Build list of available data file formats

If new DataFileFormat classes are added, they must be added to the dataFileFormats list
"""
# Build the dataFileFormats list
dataFileFormats: List[AbstractDataFileFormat] = [
    JsonDataFile,
    YamlDataFile,
]

"""
Build the available extensions list and the data file formats dictionary
"""
# Build the available extensions list
__availableExtensions: List[str] = [
    dataFileFormat.extension for dataFileFormat in dataFileFormats
]

"""
Check if all data file formats are valid
"""
# Check if the extensions are unique
if len(__availableExtensions) != len(set(__availableExtensions)):
    raise ValueError("Extensions must be unique")

# Check if the extensions are not empty
if not __availableExtensions:
    raise ValueError("Extensions must not be empty")

# Check if all extensions are strings
unvalidDataFileFormats: List[AbstractDataFileFormat] = [
    dataFileFormat
    for dataFileFormat in dataFileFormats
    if not isinstance(dataFileFormat.extension, str)
]
if unvalidDataFileFormats != []:
    # Build the string with the unvalid extensions
    unvalidExtensionsString: str = ", ".join(
        [dataFileFormat.__name__ for dataFileFormat in unvalidDataFileFormats],
    )

    #
    raise TypeError(
        f"Extension must be a string for the following AbstractDataFileFormat subclass: {unvalidExtensionsString}",
    )

# Build available extensions set
availableExtensions: Set[str] = set(__availableExtensions)

# Delete the available extensions list
del __availableExtensions

# Build the data file formats dictionary
dataFileFormatsDictionary: Dict[str, AbstractDataFileFormat] = {
    dataFileFormat.extension: dataFileFormat for dataFileFormat in dataFileFormats
}
